[gnus git] branch master updated: n0-17-403-g8bde927 =1= binhex.el (binhex-begin-line): Give it basic doc-string. starttls.el, tls.el, gnus.texi: Fix case of "GnuTLS".

Katsumi Yamaoka <[email protected]>
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  8bde9274acbf83d288a9c1b57af9403e32bc612d (commit)
      from  fb8e91794bb0ae786e66a6e656d9576d21821734 (commit)


- Log -----------------------------------------------------------------
commit 8bde9274acbf83d288a9c1b57af9403e32bc612d
Author: Glenn Morris <[email protected]>
Date:   Thu Nov 24 09:54:48 2011 +0000

    binhex.el (binhex-begin-line): Give it basic doc-string.
    starttls.el, tls.el, gnus.texi: Fix case of "GnuTLS".

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index c75520c..b8b678c 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,9 @@
+2011-11-24  Glenn Morris  <[email protected]>
+
+	* binhex.el (binhex-begin-line): Give it basic doc-string.
+
+	* starttls.el, tls.el: Fix case of "GnuTLS".
+
 2011-11-24  Juanma Barranquero  <[email protected]>
 
 	* gnus-group.el (gnus-group-highlight): Fix typo.
diff --git a/lisp/binhex.el b/lisp/binhex.el
index 5332c0f..3259346 100644
--- a/lisp/binhex.el
+++ b/lisp/binhex.el
@@ -79,10 +79,11 @@ input and write the converted data to its standard output."
 
 ;;;###autoload
 (defconst binhex-begin-line
-  "^:...............................................................$")
+  "^:...............................................................$"
+  "Regular expression matching the start of a BinHex encoded region.")
 (defconst binhex-body-line
   "^[^:]...............................................................$")
-(defconst binhex-end-line ":$")
+(defconst binhex-end-line ":$")		; unused
 
 (defvar binhex-temporary-file-directory
   (cond ((fboundp 'temp-directory) (temp-directory))
diff --git a/lisp/tls.el b/lisp/tls.el
index 42ae592..6f66156 100644
--- a/lisp/tls.el
+++ b/lisp/tls.el
@@ -123,7 +123,7 @@ successful negotiation."
 
 (defcustom tls-success "- Handshake was completed\\|SSL handshake has read "
   "Regular expression indicating completed TLS handshakes.
-The default is what GNUTLS's \"gnutls-cli\" or OpenSSL's
+The default is what GnuTLS's \"gnutls-cli\" or OpenSSL's
 \"openssl s_client\" outputs."
   :version "22.1"
   :type 'regexp
@@ -150,7 +150,7 @@ consider trustworthy, e.g.:
 (defcustom tls-untrusted
   "- Peer's certificate is NOT trusted\\|Verify return code: \\([^0] \\|.[^ ]\\)"
   "Regular expression indicating failure of TLS certificate verification.
-The default is what GNUTLS's \"gnutls-cli\" or OpenSSL's
+The default is what GnuTLS's \"gnutls-cli\" or OpenSSL's
 \"openssl s_client\" return in the event of unsuccessful
 verification."
   :type 'regexp
diff --git a/texi/ChangeLog b/texi/ChangeLog
index a4cf4f1..ab1efdf 100644
--- a/texi/ChangeLog
+++ b/texi/ChangeLog
@@ -1,3 +1,7 @@
+2011-11-24  Glenn Morris  <[email protected]>
+
+	* gnus.texi, smtpmail.texi: Fix case of "GnuTLS".
+
 2011-11-22  Paul Eggert  <[email protected]>
 
 	* gnus-refcard.tex: Spelling fix; remove trailing whitespace.
diff --git a/texi/gnus.texi b/texi/gnus.texi
index 0e372ee..8ca795b 100644
--- a/texi/gnus.texi
+++ b/texi/gnus.texi
@@ -13761,7 +13761,7 @@ The same as the above, but don't do automatic @acronym{STARTTLS} upgrades.
 @findex nntp-open-tls-stream
 @item nntp-open-tls-stream
 Opens a connection to a server over a @dfn{secure} channel.  To use
-this you must have @uref{http://www.gnu.org/software/gnutls/, GNUTLS}
+this you must have @uref{http://www.gnu.org/software/gnutls/, GnuTLS}
 installed.  You then define a server as follows:
 
 @lisp
@@ -27801,7 +27801,7 @@ The revised Gnus @acronym{FAQ} is included in the manual,
 @acronym{TLS} wrapper shipped with Gnus
 
 @acronym{TLS}/@acronym{SSL} is now supported in @acronym{IMAP} and
-@acronym{NNTP} via @file{tls.el} and GNUTLS.
+@acronym{NNTP} via @file{tls.el} and GnuTLS.
 
 @item
 Improved anti-spam features.

-----------------------------------------------------------------------
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog   |    6 ++++++
 lisp/binhex.el   |    5 +++--
 lisp/starttls.el |   30 +++++++++++++++---------------
 lisp/tls.el      |    4 ++--
 texi/ChangeLog   |    4 ++++
 texi/gnus.texi   |    4 ++--
 6 files changed, 32 insertions(+), 21 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
diff --git a/lisp/starttls.el b/lisp/starttls.el
index b995f74..58dbebf 100644
--- a/lisp/starttls.el
+++ b/lisp/starttls.el
@@ -5,7 +5,7 @@
 ;; Author: Daiki Ueno <[email protected]>
 ;; Author: Simon Josefsson <[email protected]>
 ;; Created: 1999/11/20
 ;; Keywords: TLS, SSL, OpenSSL, GNUTLS, mail, news
 
 ;; This file is part of GNU Emacs.
 
@@ -33,15 +33,15 @@
 ;; implementations both called "starttls.el".  The first one is Daiki
 ;; Ueno's starttls.el which uses his own "starttls" command line tool,
 ;; and the second one is Simon Josefsson's starttls.el which uses
-;; "gnutls-cli" from GNUTLS.
+;; "gnutls-cli" from GnuTLS.
 ;;
 ;; If "starttls" is available, it is prefered by the code over
 ;; "gnutls-cli", for backwards compatibility.  Use
 ;; `starttls-use-gnutls' to toggle between implementations if you have
 ;; both tools installed.  It is recommended to use GNUTLS, though, as
 ;; it performs more verification of the certificates.
 
-;; The GNUTLS support requires GNUTLS 0.9.90 (released 2003-10-08) or
+;; The GnuTLS support requires GnuTLS 0.9.90 (released 2003-10-08) or
 ;; later, from <http://www.gnu.org/software/gnutls/>, or "starttls"
 ;; from <ftp://ftp.opaopa.org/pub/elisp/>.
 
@@ -121,8 +121,8 @@
   :group 'mail)
 
 (defcustom starttls-gnutls-program "gnutls-cli"
-  "Name of GNUTLS command line tool.
-This program is used when GNUTLS is used, i.e. when
+  "Name of GnuTLS command line tool.
+This program is used when GnuTLS is used, i.e. when
 `starttls-use-gnutls' is non-nil."
   :version "22.1"
   :type 'string
@@ -136,7 +136,7 @@ i.e. when `starttls-use-gnutls' is nil."
   :group 'starttls)
 
 (defcustom starttls-use-gnutls (not (executable-find starttls-program))
-  "*Whether to use GNUTLS instead of the `starttls' command."
+  "*Whether to use GnuTLS instead of the `starttls' command."
   :version "22.1"
   :type 'boolean
   :group 'starttls)
@@ -150,7 +150,7 @@ These apply when the `starttls' command is used, i.e. when
 
 (defcustom starttls-extra-arguments nil
   "Extra arguments to `starttls-program'.
-These apply when GNUTLS is used, i.e. when `starttls-use-gnutls' is non-nil.
+These apply when GnuTLS is used, i.e. when `starttls-use-gnutls' is non-nil.
 
 For example, non-TLS compliant servers may require
 '(\"--protocols\" \"ssl3\").  Invoke \"gnutls-cli --help\" to
@@ -167,8 +167,8 @@ find out which parameters are available."
 
 (defcustom starttls-connect "- Simple Client Mode:\n\n"
   "*Regular expression indicating successful connection.
-The default is what GNUTLS's \"gnutls-cli\" outputs."
-  ;; GNUTLS cli.c:main() prints this string when it is starting to run
+The default is what GnuTLS's \"gnutls-cli\" outputs."
+  ;; GnuTLS cli.c:main() prints this string when it is starting to run
   ;; in the application read/write phase.  If the logic, or the string
   ;; itself, is modified, this must be updated.
   :version "22.1"
@@ -177,8 +177,8 @@ The default is what GNUTLS's \"gnutls-cli\" outputs."
 
 (defcustom starttls-failure "\\*\\*\\* Handshake has failed"
   "*Regular expression indicating failed TLS handshake.
-The default is what GNUTLS's \"gnutls-cli\" outputs."
-  ;; GNUTLS cli.c:do_handshake() prints this string on failure.  If the
+The default is what GnuTLS's \"gnutls-cli\" outputs."
+  ;; GnuTLS cli.c:do_handshake() prints this string on failure.  If the
   ;; logic, or the string itself, is modified, this must be updated.
   :version "22.1"
   :type 'regexp
@@ -186,8 +186,8 @@ The default is what GNUTLS's \"gnutls-cli\" outputs."
 
 (defcustom starttls-success "- Compression: "
   "*Regular expression indicating completed TLS handshakes.
-The default is what GNUTLS's \"gnutls-cli\" outputs."
-  ;; GNUTLS cli.c:do_handshake() calls, on success,
+The default is what GnuTLS's \"gnutls-cli\" outputs."
+  ;; GnuTLS cli.c:do_handshake() calls, on success,
   ;; common.c:print_info(), that unconditionally print this string
   ;; last.  If that logic, or the string itself, is modified, this
   ;; must be updated.
@@ -283,7 +283,7 @@ BUFFER is the buffer (or `buffer-name') to associate with the process.
 Third arg is name of the host to connect to, or its IP address.
 Fourth arg PORT is an integer specifying a port to connect to.
 If `starttls-use-gnutls' is nil, this may also be a service name, but
-GNUTLS requires a port number."
+GnuTLS requires a port number."
   (if starttls-use-gnutls
       (starttls-open-stream-gnutls name buffer host port)
     (message "Opening STARTTLS connection to `%s:%s'" host (format "%s" port))
@@ -5,7 +5,7 @@
 ;; Author: Simon Josefsson <[email protected]>
 ;; Created: 1999/11/20
-;; Keywords: TLS, SSL, OpenSSL, GNUTLS, mail, news
+;; Keywords: TLS, SSL, OpenSSL, GnuTLS, mail, news
 
 ;; This file is part of GNU Emacs.
@@ -33,15 +33,15 @@
 ;; "gnutls-cli", for backwards compatibility.  Use
 ;; `starttls-use-gnutls' to toggle between implementations if you have
-;; both tools installed.  It is recommended to use GNUTLS, though, as
+;; both tools installed.  It is recommended to use GnuTLS, though, as
 ;; it performs more verification of the certificates.
 
-- 
Gnus Project
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.